"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/releasesSlice/selectors.ts
var selectors_exports = {};
__export(selectors_exports, {
  getHasReleases: () => getHasReleases,
  getReleaseListState: () => getReleaseListState,
  getReleaseTags: () => getReleaseTags,
  getReleaseTagsById: () => getReleaseTagsById,
  getReleasesById: () => getReleasesById,
  getReleasesList: () => getReleasesList,
  getSelectedRelease: () => getSelectedRelease,
  getUpdateTypes: () => getUpdateTypes
});
module.exports = __toCommonJS(selectors_exports);

// src/utils.ts
var import_helpers = require("@northern.tech/utils/helpers");

// src/commonConstants.tsx
var import_js = require("@mdi/js");
var import_jsx_runtime = require("react/jsx-runtime");
var timeUnits = {
  days: "days",
  minutes: "minutes",
  hours: "hours"
};
var DEVICE_LIST_MAXIMUM_LENGTH = 50;
var DEVICE_FILTERING_OPTIONS = {
  $eq: { key: "$eq", title: "equals", shortform: "=" },
  $ne: { key: "$ne", title: "not equal", shortform: "!=" },
  $gt: {
    key: "$gt",
    title: ">",
    shortform: ">",
    help: 'The "greater than" operator can work both on numbers and strings. In the latter case, the operator applies the lexicographical order to the value strings.'
  },
  $gte: {
    title: ">=",
    shortform: ">=",
    help: 'The "greater than or equal" operator can work both on numbers and strings. In the latter case, the operator applies the lexicographical order to the value strings.'
  },
  $lt: {
    key: "$lt",
    title: "<",
    shortform: "<",
    help: 'The "lesser than" operator can work both on numbers and strings. In the latter case, the operator applies the lexicographical order to the value strings.'
  },
  $lte: {
    title: "<=",
    shortform: "<=",
    help: 'The "lesser than or equal" operator can work both on numbers and strings. In the latter case, the operator applies the lexicographical order to the value strings.'
  },
  $ltne: {
    key: "$ltne",
    title: "$ltne",
    shortform: "ltne",
    help: 'The "lesser than or does not exist" operator can work both on numbers and strings. In the latter case, the operator applies the lexicographical order to the value strings.'
  },
  $in: {
    key: "$in",
    title: "in",
    shortform: "in",
    help: 'The "in" operator accepts a list of comma-separated values. It matches if the selected field is equal to one of the specified values.'
  },
  $nin: {
    key: "$nin",
    title: "not in",
    shortform: "not in",
    help: `The "not in" operator accepts a list of comma-separated values. It matches if the selected field's value is not equal to any of the specified options.`
  },
  $exists: {
    key: "$exists",
    title: "exists",
    shortform: "exists",
    value: true,
    help: `The "exists" operator matches if the selected field's value has a value. No value needs to be provided for this operator.`
  },
  $nexists: {
    key: "$nexists",
    title: `doesn't exist`,
    shortform: `doesn't exist`,
    value: true,
    help: `The "doesn't exist" operator matches if the selected field's value has no value. No value needs to be provided for this operator.`
  },
  $regex: {
    key: "$regex",
    title: `matches regular expression`,
    shortform: `matches`,
    help: `The "regular expression" operator matches the selected field's value with a Perl compatible regular expression (PCRE), automatically anchored by ^. If the regular expression is not valid, the filter will produce no results. If you need to specify options and flags, you can provide the full regex in the format of /regex/flags, for example.`
  }
};
var DEVICE_ISSUE_OPTIONS = {
  issues: {
    isCategory: true,
    key: "issues",
    title: "Devices with issues",
    filterRule: {}
  },
  offline: {
    issueCategory: "issues",
    key: "offline",
    needsFullFiltering: true,
    needsMonitor: false,
    needsReporting: false,
    filterRule: {
      scope: "system",
      key: "check_in_time",
      operator: DEVICE_FILTERING_OPTIONS.$ltne.key,
      value: ({ offlineThreshold }) => offlineThreshold
    },
    title: "Offline devices"
  },
  failedLastUpdate: {
    issueCategory: "issues",
    key: "failedLastUpdate",
    needsFullFiltering: false,
    needsMonitor: false,
    needsReporting: true,
    filterRule: { scope: "monitor", key: "failed_last_update", operator: DEVICE_FILTERING_OPTIONS.$eq.key, value: true },
    title: "Deployment failed"
  },
  monitoring: {
    issueCategory: "issues",
    key: "monitoring",
    needsFullFiltering: false,
    needsMonitor: true,
    needsReporting: false,
    filterRule: { scope: "monitor", key: "alerts", operator: DEVICE_FILTERING_OPTIONS.$eq.key, value: true },
    title: "Monitoring alert"
  },
  authRequests: {
    key: "authRequests",
    needsFullFiltering: false,
    needsMonitor: false,
    needsReporting: true,
    filterRule: { scope: "monitor", key: "auth_requests", operator: DEVICE_FILTERING_OPTIONS.$gt.key, value: 1 },
    title: "Devices with new authentication requests"
  },
  gatewayDevices: {
    key: "gatewayDevices",
    needsFullFiltering: false,
    needsMonitor: false,
    needsReporting: true,
    filterRule: { scope: "inventory", key: "mender_is_gateway", operator: DEVICE_FILTERING_OPTIONS.$eq.key, value: "true" },
    title: "Gateway devices"
  }
};
var oneSecond = 1e3;
var TIMEOUTS = {
  debounceDefault: 700,
  debounceShort: 300,
  halfASecond: 0.5 * oneSecond,
  oneSecond,
  twoSeconds: 2 * oneSecond,
  threeSeconds: 3 * oneSecond,
  fiveSeconds: 5 * oneSecond,
  refreshDefault: 10 * oneSecond,
  refreshLong: 60 * oneSecond
};
var DEVICE_ONLINE_CUTOFF = { interval: 1, intervalName: timeUnits.days };
var ATTRIBUTE_SCOPES = {
  inventory: "inventory",
  identity: "identity",
  monitor: "monitor",
  system: "system",
  tags: "tags"
};
var defaultIdAttribute = Object.freeze({ attribute: "id", scope: ATTRIBUTE_SCOPES.identity });
var credentialTypes = {
  aws: "aws",
  http: "http",
  sas: "sas",
  x509: "x509"
};
var EXTERNAL_PROVIDER = {
  "iot-core": {
    credentialsType: credentialTypes.aws,
    icon: import_js.mdiAws,
    title: "AWS IoT Core",
    twinTitle: "Device Shadow",
    provider: "iot-core",
    enabled: true,
    deviceTwin: true,
    configHint: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_jsx_runtime.Fragment, { children: "For help finding your AWS IoT Core connection string, check the AWS IoT documentation." })
  },
  "iot-hub": {
    credentialsType: credentialTypes.sas,
    icon: import_js.mdiMicrosoftAzure,
    title: "Azure IoT Hub",
    twinTitle: "Device Twin",
    provider: "iot-hub",
    enabled: true,
    deviceTwin: true,
    configHint: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", { children: [
      "For help finding your Azure IoT Hub connection string, look under 'Shared access policies' in the Microsoft Azure UI as described",
      " ",
      /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
        "a",
        {
          href: "https://devblogs.microsoft.com/iotdev/understand-different-connection-strings-in-azure-iot-hub/#iothubconn",
          target: "_blank",
          rel: "noopener noreferrer",
          children: "here"
        }
      ),
      "."
    ] })
  },
  webhook: {
    credentialsType: credentialTypes.http,
    deviceTwin: false,
    // disable the webhook provider here, since it is treated different than other integrations, with a custom configuration & management view, etc.
    enabled: false,
    provider: "webhook"
  }
};
var emptyUiPermissions = Object.freeze({
  auditlog: [],
  deployments: [],
  groups: Object.freeze({}),
  releases: Object.freeze({}),
  tenantManagement: [],
  userManagement: []
});
var emptyRole = Object.freeze({
  name: void 0,
  description: "",
  permissions: [],
  uiPermissions: Object.freeze({ ...emptyUiPermissions })
});

// src/utils.ts
var filterAliases = {
  $nexists: { alias: DEVICE_FILTERING_OPTIONS.$exists.key, value: false }
};
var listItemMapper = (byId, ids, { defaultObject = {}, cutOffSize = DEVICE_LIST_MAXIMUM_LENGTH }) => {
  return ids.slice(0, cutOffSize).reduce((accu, id) => {
    if (id && byId[id]) {
      accu.push({ ...defaultObject, ...byId[id] });
    }
    return accu;
  }, []);
};

// src/releasesSlice/selectors.ts
var import_toolkit = require("@reduxjs/toolkit");
var getSelectedReleaseId = (state) => state.releases.selectedRelease;
var getReleasesById = (state) => state.releases.byId;
var getReleaseTags = (state) => state.releases.tags;
var getReleaseListState = (state) => state.releases.releasesList;
var getListedReleases = (state) => state.releases.releasesList.releaseIds;
var getUpdateTypes = (state) => state.releases.updateTypes;
var getReleaseMappingDefaults = () => ({});
var getReleasesList = (0, import_toolkit.createSelector)([getReleasesById, getListedReleases, getReleaseMappingDefaults], listItemMapper);
var getReleaseTagsById = (0, import_toolkit.createSelector)([getReleaseTags], (releaseTags) => releaseTags.reduce((accu, key) => ({ ...accu, [key]: key }), {}));
var getHasReleases = (0, import_toolkit.createSelector)(
  [getReleaseListState, getReleasesById],
  ({ searchTotal, total }, byId) => !!(Object.keys(byId).length || total || searchTotal)
);
var getSelectedRelease = (0, import_toolkit.createSelector)([getReleasesById, getSelectedReleaseId], (byId, id) => byId[id] ?? {});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getHasReleases,
  getReleaseListState,
  getReleaseTags,
  getReleaseTagsById,
  getReleasesById,
  getReleasesList,
  getSelectedRelease,
  getUpdateTypes
});
//# sourceMappingURL=selectors.cjs.map